var svg = d3.select('svg');
  
var margin = 80;
var width = 990 - 2 * margin;
var height = 490 - 2 * margin;

const csvUrl =
  'https://gist.githubusercontent.com/KishenPatel97/5c07a91047a15b23ace0e597e11fe83f/raw/0f3e7af7535916da09af348824d2a719f8229729/Car_details.csv'

d3.csv('data.csv').then(function(data){

// Creation du graphe + translation mathématique
  var chart = svg.append('g')
    .attr('transform', `translate(${margin}, ${margin})`);

// Axe des y  
  var yScale = d3.scaleLinear()
    .range([height, 0])
    .domain([0, 800000]);
  
  chart.append('g')
    .call(d3.axisLeft(yScale));
  
// Axe des ordonnées 
  var xScale = d3.scaleBand()
    .range([0, width])
    .domain(data.map((data) => data.name))
    .padding(0.2);

  chart.append('g')
      .attr('transform', `translate(0, ${height})`)
      .call(d3.axisBottom(xScale));

// Dessiner des gridlines
	chart.append('g')
      .attr('class', 'grid')
      .call(d3.axisLeft()
          .scale(yScale)
          .tickSize(-width, 0, 0)
          .tickFormat(''));
  
// Ajouter des titres au graphe
// Titre à gauche
  	svg.append('text')
      .attr('x', -(height / 2) - margin)
      .attr('y', margin / 5)
      .attr('transform', 'rotate(-90)')
      .attr('text-anchor', 'middle')
      .text('Selling Price ($)');
// Titre en haut
  	svg.append('text')
      .attr('class','title')
      .attr('x', width / 2 + margin)
      .attr('y', 40)
      .attr('text-anchor', 'middle')
      .text('Highest selling price for vehicles');
// Titre en bas
  	svg.append('text')
      .attr('x', width / 2 + margin)
      .attr('y', height + 120)
      .attr('text-anchor', 'middle')
      .text('Vehicle Brand');
      
// Lier les elements de l'array DOM element
  var barGroups = chart.selectAll()
  .data(data)
  .enter()
  .append('g');

  console.log(data);

// Dessiner des barres liées à chaque element des données
  barGroups
    .append('rect')
    .attr('class', 'bar')
    .attr('x', (data) => xScale(data.name))
    .attr('y', (data) => yScale(data.selling_price))
    .attr('height', (data) => height - yScale(data.selling_price))
    .attr('width', xScale.bandwidth());
  
  //Afficher la valeur sur chaque barre
  barGroups 
      .append('text')
      .attr('class', 'value')
      .attr('x', (data) => xScale(data.name) + xScale.bandwidth() / 2)
      .attr('y', (data) => yScale(data.selling_price) + 30)
      .attr('text-anchor', 'middle')
      .text((data) => `${data.selling_price}%`)

// Event Listener: mouse enter
    barGroups.on('mouseenter', function (actual, i) {
      d3.selectAll('.value')
            .attr('opacity', 0)
       
      d3.select(this)
        .transition()
        .duration(300)
        .attr('opacity', 0.6);

      var y = yScale(actual.selling_price);

      line = chart.append('line')
        .attr('id', 'limit')
        .attr('x1', 0)
        .attr('y1', y)
        .attr('x2', width)
        .attr('y2', y);

      barGroups.append('text')
        .attr('class', 'divergence')
        .attr('x', (data) => xScale(data.name) + xScale.bandwidth() / 2)
        .attr('y', (data) => yScale(data.selling_price) + 30)
        .attr('fill', 'white')
        .attr('text-anchor', 'middle')
        .text((data, idx) => {
          var divergence = (data.selling_price - actual.selling_price).toFixed(1)

          let text = ''
          if (divergence > 0) text += '+'
          text += `${divergence}%`

          return idx !== i ? text : ''; 
        })
    })

//Event Listener: mouse leave
    barGroups.on('mouseleave', function () {
      d3.selectAll('.value')
        .attr('opacity', 1)

      d3.select(this)
        .transition()
        .duration(300)
        .attr('opacity', 1)
        .attr('x', (data) => xScale(data.name))
        .attr('width', xScale.bandwidth())

      chart.selectAll('#limit').remove()
      chart.selectAll('.divergence').remove()
  }